v0.2.0 (2020-11-29)
-------------------
- Now support only Python 3.6 and up (tested through 3.9) and PyPy3
- Add type annotations
- Add API documentation to README

v0.1.0 (2017-11-26)
-------------------
Initial release
